<?php

/**
 * @file
 * Hooks provided by this module.
 *
 * Copyright (C) 2025  Library Solutions, LLC (et al.).
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Alter a field definition before using it to build an entity form.
 *
 * This hook is invoked for each field which is both a candidate for display and
 * has a configurable definition.
 *
 * @param \Drupal\Core\Field\BaseFieldDefinition|\Drupal\Core\Field\FieldConfigInterface|\Drupal\Core\Field\FieldDefinition $definition
 *   The configurable field definition to alter.
 * @param array $context
 *   An associative array containing:
 *   - form_mode: The form mode identifier.
 *   - third_party_settings: The third party settings for the form.
 */
function hook_entity_form_display_field_definition_alter(\Drupal\Core\Field\BaseFieldDefinition|\Drupal\Core\Field\FieldConfigInterface|\Drupal\Core\Field\FieldDefinition $definition, array $context) {
  $module = 'example_module_name';
  $settings = $context['third_party_settings'][$module] ?? [];

  /** @var string|\Stringable */
  $label = $settings['label'] ?? '';
  if ($label !== '') {
    $definition->setLabel($label);
  }

  /** @var string|\Stringable */
  $description = $settings['description'] ?? '';
  if ($description !== '') {
    $definition->setDescription($description);
  }

  if (!empty($settings['required'])) {
    $definition->setRequired(TRUE);
  }

  /** @var array */
  $default_value = $settings['default_value'] ?? [];
  if ($default_value !== []) {
    $definition->setDefaultValue($default_value);
  }
}

/**
 * @} End of "addtogroup hooks".
 */
